@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.96 2005/04/19 11:14:41 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.97 2005/06/16 12:38:13 chpe Exp $
  */
 
 #include "config.h"
@@ -261,7 +261,7 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 	button = gtk_button_new_with_label (_("Cl_ear"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
-	gtk_widget_show (image);
+	/* don't show the image! see bug #307818 */
 	gtk_widget_show (button);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_ACCEPT);
 	
